@@ -55,13 +55,13 @@ __all__ = [  # will be updated in below
     'NA',
     'UINT_MAX',
     'ULONGLONG_MAX',
+    'NVMLError',
     'nvmlCheckReturn',
-    'nvmlQuery',
-    'nvmlQueryFieldValues',
     'nvmlInit',
     'nvmlInitWithFlags',
+    'nvmlQuery',
+    'nvmlQueryFieldValues',
     'nvmlShutdown',
-    'NVMLError',
 ]
 
 
@@ -174,7 +174,14 @@ del (
 
 # 5. Add explicit references to appease linters
 # pylint: disable=no-member
-c_nvmlDevice_t: _TypeAlias = _pynvml.c_nvmlDevice_t  # noqa: PYI042
+if _TYPE_CHECKING:
+    # pylint: disable-next=missing-class-docstring,too-few-public-methods,function-redefined
+    class c_nvmlDevice_t(_ctypes.c_void_p):
+        pass
+
+else:
+    c_nvmlDevice_t: _TypeAlias = _pynvml.c_nvmlDevice_t  # type: ignore[no-redef] # noqa: PYI042
+
 c_nvmlFieldValue_t: _TypeAlias = _pynvml.c_nvmlFieldValue_t  # noqa: PYI042
 NVML_SUCCESS: int = _pynvml.NVML_SUCCESS
 NVML_ERROR_INSUFFICIENT_SIZE: int = _pynvml.NVML_ERROR_INSUFFICIENT_SIZE
@@ -377,6 +384,7 @@ def nvmlShutdown() -> None:  # pylint: disable=function-redefined
 
 def nvmlQuery(
     func: _Callable[..., _Any] | str,
+    /,
     *args: _Any,
     default: _Any = NA,
     ignore_errors: bool = True,
@@ -513,7 +521,7 @@ def nvmlQueryFieldValues(
     return values_with_timestamps
 
 
-def nvmlCheckReturn(retval: _Any, types: type | tuple[type, ...] | None = None) -> bool:
+def nvmlCheckReturn(retval: _Any, types: type | tuple[type, ...] | None = None, /) -> bool:
     """Check whether the return value is not :const:`nvitop.NA` and is one of the given types."""
     if types is None:
         return retval != NA
@@ -584,7 +592,7 @@ if not _pynvml_installation_corrupted:
             'usedGpuCcProtectedMemory': '%d B',
         }
 
-    __get_running_processes_version_suffix = None
+    __get_running_processes_version_suffix: str | None = None
     c_nvmlProcessInfo_t = c_nvmlProcessInfo_v3_t
 
     def __determine_get_running_processes_version_suffix() -> str:
@@ -643,6 +651,7 @@ if not _pynvml_installation_corrupted:
 
     def __nvml_device_get_running_processes(
         func: str,
+        /,
         handle: c_nvmlDevice_t,
     ) -> list[c_nvmlProcessInfo_t]:
         """Helper function for :func:`nvmlDeviceGet{Compute,Graphics,MPSCompute}RunningProcesses`.
@@ -802,7 +811,7 @@ if not _pynvml_installation_corrupted:
         _fmt_: _ClassVar[dict[str, str]] = {'<default>': '%d B'}
 
     nvmlMemory_v2 = getattr(_pynvml, 'nvmlMemory_v2', _ctypes.sizeof(c_nvmlMemory_v2_t) | 2 << 24)
-    __get_memory_info_version_suffix = None
+    __get_memory_info_version_suffix: str | None = None
     c_nvmlMemory_t = c_nvmlMemory_v2_t
 
     def __determine_get_memory_info_version_suffix() -> str:
