@@ -4,7 +4,7 @@
 # pylint: disable=missing-module-docstring
 
 from nvitop.tui.library import (
-    SUPERUSER,
+    IS_SUPERUSER,
     USERNAME,
     Device,
     colored,
@@ -13,3 +13,15 @@ from nvitop.tui.library import (
     setlocale_utf8,
 )
 from nvitop.tui.tui import TUI
+
+
+__all__ = [
+    'IS_SUPERUSER',
+    'TUI',
+    'USERNAME',
+    'Device',
+    'colored',
+    'libcurses',
+    'set_color',
+    'setlocale_utf8',
+]
