@@ -99,7 +99,7 @@ class DevicePanel(BasePanel):  # pylint: disable=too-many-instance-attributes
             '│ {memory_usage:>20} │ {gpu_utilization_string:>7}  {compute_mode:>11} │',
         ]
         self.formats_full: list[str] = [
-            '│ {physical_index:>3}  {name:<18}  {persistence_mode:<4} '
+            '│ {physical_index:>3}  {name:<19} {persistence_mode:>4} '
             '│ {bus_id:<16} {display_active:>3} │ {total_volatile_uncorrected_ecc_errors:>20} │',
             '│ {fan_speed_string:>3}  {temperature_string:>4}  {performance_state:>4}  {power_status:>12} '
             '│ {memory_usage:>20} │ {gpu_utilization_string:>7}  {compute_mode:>11} │',
@@ -181,7 +181,7 @@ class DevicePanel(BasePanel):  # pylint: disable=too-many-instance-attributes
                         else f'{round(device.bar1_memory_percent)}%'
                     )
             else:
-                device.name = cut_string(device.name, maxlen=18, padstr='..', align='right')
+                device.name = cut_string(device.name, maxlen=19, padstr='..', align='right')
                 device.current_driver_model = device.current_driver_model.replace('WDM', 'TCC')
                 device.display_active = device.display_active.replace('Enabled', 'On').replace(
                     'Disabled',
